diff --git a/cps.py b/cps.py
index 00d0f356..fdc5bce7 100755
--- a/cps.py
+++ b/cps.py
@@ -22,8 +22,8 @@ if __name__ == '__main__':
IOLoop.instance().start()
if web.helper.global_task == 0:
- print("Performing restart of Calibre-web")
+ web.app.logger.info("Performing restart of Calibre-web")
os.execl(sys.executable, sys.executable, *sys.argv)
else:
- print("Performing shutdown of Calibre-web")
+ web.app.logger.info("Performing shutdown of Calibre-web")
sys.exit(0)
diff --git a/cps/db.py b/cps/db.py
index f6ee790e..e4082a16 100755
--- a/cps/db.py
+++ b/cps/db.py
@@ -56,6 +56,10 @@ books_languages_link = Table('books_languages_link', Base.metadata,
Column('lang_code', Integer, ForeignKey('languages.id'), primary_key=True)
)
+books_publishers_link = Table('books_publishers_link', Base.metadata,
+ Column('book', Integer, ForeignKey('books.id'), primary_key=True),
+ Column('publisher', Integer, ForeignKey('publishers.id'), primary_key=True)
+ )
class Identifiers(Base):
__tablename__ = 'identifiers'
@@ -182,6 +186,21 @@ class Languages(Base):
def __repr__(self):
return u"".format(self.lang_code)
+class Publishers(Base):
+ __tablename__ = 'publishers'
+
+ id = Column(Integer, primary_key=True)
+ name = Column(String)
+ sort = Column(String)
+
+ def __init__(self, name,sort):
+ self.name = name
+ self.sort = sort
+
+ def __repr__(self):
+ return u"".format(self.name, self.sort)
+
+
class Data(Base):
__tablename__ = 'data'
@@ -224,6 +243,7 @@ class Books(Base):
series = relationship('Series', secondary=books_series_link, backref='books')
ratings = relationship('Ratings', secondary=books_ratings_link, backref='books')
languages = relationship('Languages', secondary=books_languages_link, backref='books')
+ publishers = relationship('Publishers', secondary=books_publishers_link, backref='books')
identifiers = relationship('Identifiers', backref='books')
def __init__(self, title, sort, author_sort, timestamp, pubdate, series_index, last_modified, path, has_cover,
diff --git a/cps/helper.py b/cps/helper.py
index 20d9402a..5e9c9210 100755
--- a/cps/helper.py
+++ b/cps/helper.py
@@ -338,7 +338,7 @@ class Updater(threading.Thread):
def reduce_files(self, remove_items, exclude_items):
rf = []
for item in remove_items:
- if not item in exclude_items:
+ if not item.startswith(exclude_items):
rf.append(item)
return rf
@@ -347,15 +347,14 @@ class Updater(threading.Thread):
if sys.platform == "win32" or sys.platform == "darwin":
change_permissions = False
else:
- app.logger.debug('Update on OS-System : ' + sys.platform)
- # print('OS-System: '+sys.platform )
+ logging.getLogger('cps.web').debug('Update on OS-System : ' + sys.platform)
new_permissions = os.stat(root_dst_dir)
# print new_permissions
for src_dir, dirs, files in os.walk(root_src_dir):
dst_dir = src_dir.replace(root_src_dir, root_dst_dir, 1)
if not os.path.exists(dst_dir):
os.makedirs(dst_dir)
- # print('Create-Dir: '+dst_dir)
+ logging.getLogger('cps.web').debug('Create-Dir: '+dst_dir)
if change_permissions:
# print('Permissions: User '+str(new_permissions.st_uid)+' Group '+str(new_permissions.st_uid))
os.chown(dst_dir, new_permissions.st_uid, new_permissions.st_gid)
@@ -365,27 +364,28 @@ class Updater(threading.Thread):
if os.path.exists(dst_file):
if change_permissions:
permission = os.stat(dst_file)
- # print('Remove file before copy: '+dst_file)
+ logging.getLogger('cps.web').debug('Remove file before copy: '+dst_file)
os.remove(dst_file)
else:
if change_permissions:
permission = new_permissions
shutil.move(src_file, dst_dir)
- # print('Move File '+src_file+' to '+dst_dir)
+ logging.getLogger('cps.web').debug('Move File '+src_file+' to '+dst_dir)
if change_permissions:
try:
os.chown(dst_file, permission.st_uid, permission.st_uid)
# print('Permissions: User '+str(new_permissions.st_uid)+' Group '+str(new_permissions.st_uid))
except:
e = sys.exc_info()
- # print('Fail '+str(dst_file)+' error: '+str(e))
+ logging.getLogger('cps.web').debug('Fail '+str(dst_file)+' error: '+str(e))
return
def update_source(self, source, destination):
# destination files
old_list = list()
exclude = (
- ['vendor' + os.sep + 'kindlegen.exe', 'vendor' + os.sep + 'kindlegen', '/app.db', 'vendor', '/update.py'])
+ 'vendor' + os.sep + 'kindlegen.exe', 'vendor' + os.sep + 'kindlegen', os.sep + 'app.db',
+ os.sep + 'vendor',os.sep + 'calibre-web.log')
for root, dirs, files in os.walk(destination, topdown=True):
for name in files:
old_list.append(os.path.join(root, name).replace(destination, ''))
@@ -410,12 +410,14 @@ class Updater(threading.Thread):
for item in remove_items:
item_path = os.path.join(destination, item[1:])
if os.path.isdir(item_path):
- app.logger.debug("Delete dir " + item_path)
+ logging.getLogger('cps.web').debug("Delete dir " + item_path)
shutil.rmtree(item_path)
else:
try:
- app.logger.debug("Delete file " + item_path)
+ logging.getLogger('cps.web').debug("Delete file " + item_path)
+ log_from_thread("Delete file " + item_path)
os.remove(item_path)
except:
- app.logger.debug("Could not remove:" + item_path)
+ logging.getLogger('cps.web').debug("Could not remove:" + item_path)
shutil.rmtree(source, ignore_errors=True)
+
diff --git a/cps/templates/detail.html b/cps/templates/detail.html
index 8775f079..0a5167b6 100644
--- a/cps/templates/detail.html
+++ b/cps/templates/detail.html
@@ -50,6 +50,7 @@
{% if entry.identifiers|length > 0 %}
{% endif %}
+ {% if entry.publishers|length > 0 %}
+
+
+ {{_('Publisher')}}:{% for publisher in entry.publishers %} {{publisher.name}}{% if not loop.last %},{% endif %}{% endfor %}
+
+
+ {% endif %}
{% if entry.pubdate[:10] != '0101-01-01' %}
{{_('Publishing date')}}: {{entry.pubdate|formatdate}}
{% endif %}
diff --git a/cps/templates/search_form.html b/cps/templates/search_form.html
index 2e9f4d3d..e61195ec 100644
--- a/cps/templates/search_form.html
+++ b/cps/templates/search_form.html
@@ -10,63 +10,67 @@
-
+
+
+
+
+
-
+
-
+
-
+
{% if languages %}
-
+
-
+
{% for language in languages %}
{% endfor %}
diff --git a/cps/web.py b/cps/web.py
index 5c1cb975..a33748e0 100755
--- a/cps/web.py
+++ b/cps/web.py
@@ -473,8 +473,10 @@ def feed_search(term):
filter = True
if term:
entries = db.session.query(db.Books).filter(db.or_(db.Books.tags.any(db.Tags.name.like("%" + term + "%")),
- db.Books.authors.any(db.Authors.name.like("%" + term + "%")),
- db.Books.title.like("%" + term + "%"))).filter(filter).all()
+ db.Books.series.any(db.Series.name.like("%" + term + "%")),
+ db.Books.authors.any(db.Authors.name.like("%" + term + "%")),
+ db.Books.publishers.any(db.Publishers.name.like("%" + term + "%")),
+ db.Books.title.like("%" + term + "%"))).filter(filter).all()
entriescount = len(entries) if len(entries) > 0 else 1
pagination = Pagination(1, entriescount, entriescount)
xml = render_title_template('feed.xml', searchterm=term, entries=entries, pagination=pagination)
@@ -744,7 +746,10 @@ def get_updater_status():
helper.updater_thread.start()
status['status']=helper.updater_thread.get_update_status()
elif request.method == "GET":
- status['status']=helper.updater_thread.get_update_status()
+ try:
+ status['status']=helper.updater_thread.get_update_status()
+ except:
+ status['status'] = 7
return json.dumps(status)
@@ -1044,9 +1049,9 @@ def stats():
@login_required
@admin_required
def shutdown():
- global global_task
+ # global global_task
task = int(request.args.get("parameter").strip())
- global_task = task
+ helper.global_task = task
if task == 1 or task == 0: # valid commandos received
# close all database connections
db.session.close()
@@ -1084,9 +1089,10 @@ def search():
else:
filter = True
entries = db.session.query(db.Books).filter(db.or_(db.Books.tags.any(db.Tags.name.like("%" + term + "%")),
- db.Books.series.any(db.Series.name.like("%" + term + "%")),
- db.Books.authors.any(db.Authors.name.like("%" + term + "%")),
- db.Books.title.like("%" + term + "%"))).filter(filter).all()
+ db.Books.series.any(db.Series.name.like("%" + term + "%")),
+ db.Books.authors.any(db.Authors.name.like("%" + term + "%")),
+ db.Books.publishers.any(db.Publishers.name.like("%" + term + "%")),
+ db.Books.title.like("%" + term + "%"))).filter(filter).all()
return render_title_template('search.html', searchterm=term, entries=entries)
else:
return render_title_template('search.html', searchterm="")
@@ -1106,12 +1112,14 @@ def advanced_search():
author_name = request.args.get("author_name")
book_title = request.args.get("book_title")
+ publisher = request.args.get("publisher")
if author_name: author_name = author_name.strip()
if book_title: book_title = book_title.strip()
+ if publisher: publisher = publisher.strip()
if include_tag_inputs or exclude_tag_inputs or include_series_inputs or exclude_series_inputs or \
include_languages_inputs or exclude_languages_inputs or author_name or book_title:
searchterm = []
- searchterm.extend((author_name, book_title))
+ searchterm.extend((author_name, book_title, publisher))
tag_names = db.session.query(db.Tags).filter(db.Tags.id.in_(include_tag_inputs)).all()
searchterm.extend(tag.name for tag in tag_names)
# searchterm = " + ".join(filter(None, searchterm))
@@ -1127,7 +1135,8 @@ def advanced_search():
searchterm.extend(language.name for language in language_names)
searchterm = " + ".join(filter(None, searchterm))
q = q.filter(db.Books.authors.any(db.Authors.name.like("%" + author_name + "%")),
- db.Books.title.like("%" + book_title + "%"))
+ db.Books.title.like("%" + book_title + "%"),
+ db.Books.publishers.any(db.Publishers.name.like("%" + publisher + "%")))
for tag in include_tag_inputs:
q = q.filter(db.Books.tags.any(db.Tags.id == tag))
for tag in exclude_tag_inputs:
@@ -1611,7 +1620,7 @@ def basic_configuration():
def configuration_helper(origin):
- global global_task
+ # global global_task
reboot_required = False
db_change = False
success = False
@@ -1686,7 +1695,7 @@ def configuration_helper(origin):
# stop tornado server
server = IOLoop.instance()
server.add_callback(server.stop)
- global_task = 0
+ helper.global_task = 0
app.logger.info('Reboot required, restarting')
if origin:
success = True
@@ -1106,12 +1112,14 @@ def advanced_search():
if include_tag_inputs or exclude_tag_inputs or include_series_inputs or exclude_series_inputs or \
- include_languages_inputs or exclude_languages_inputs or author_name or book_title:
+ include_languages_inputs or exclude_languages_inputs or author_name or book_title or publisher:
searchterm = []